==> nextcloud-14.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/ca.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Carregant vista prèvia ...",
    "Saved" : "Guardat",
    "Admin" : "Admin",
    "a safe home for all your data" : "un lloc segur per a les teves dades",
    "Name cannot be empty" : "El nom del fitxer no pot estar buit",
    "The given name is too long" : "El nom introduït és massa llarg",
    "The given web address is too long" : "L'adreça web proporcionada és massa llarga",
    "The given slogan is too long" : "El lema indicat és massa llarg",
    "The given color is invalid" : "El color donat no és vàlid",
    "No file uploaded" : "No s'ha carregat cap fitxer",
    "Unsupported image type" : "Tipus d'imatge no compatible",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Ja estàs utilitzant un tema propi. La configuració de l'app s'hauria d'haver modificat.",
    "Theming" : "Aparença",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "La personalització permet canviar fàcilment l'aspecte de la vostra web i dels clients. Això serà visible per a tots els usuaris.",
    "Name" : "Nom",
    "Reset to default" : "Restablir al valor predeterminat",
    "Slogan" : "Lema",
    "Color" : "Color",
    "Logo" : "Logotip",
    "Upload new logo" : "Penjar un nou logotip",
    "Login image" : "Login logo",
    "Upload new login background" : "Carregar nou fons d'inici de sessió",
    "Remove background image" : "Elimina la imatge de fons",
    "Header logo" : "Logo de capçalera",
    "Upload new header logo" : "Pujar un nou logo de capçalera",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instal·la l'extensió Imagemagick per al PHP i es generarà automàticament un favicon a partir del logo i del color del tema.",
    "You are already using a custom theme" : "Ja esteu utilitzant un tema personalitzat",
    "reset to default" : "restablir a configuració predeterminada",
    "Web address" : "Adreça web",
    "Web address https://…" : "Adreça del servidor https://…"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/ca.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Carregant vista prèvia ...",
    "Saved" : "Guardat",
    "Admin" : "Admin",
    "a safe home for all your data" : "un lloc segur per a les teves dades",
    "Name cannot be empty" : "El nom del fitxer no pot estar buit",
    "The given name is too long" : "El nom introduït és massa llarg",
    "The given web address is too long" : "L'adreça web proporcionada és massa llarga",
    "The given slogan is too long" : "El lema indicat és massa llarg",
    "The given color is invalid" : "El color donat no és vàlid",
    "The file was uploaded" : "S'ha carregat el fitxer",
    "No file was uploaded" : "No s'ha carregat cap fitxer",
    "No file uploaded" : "No s'ha carregat cap fitxer",
    "Unsupported image type" : "Tipus d'imatge no compatible",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Ja estàs utilitzant un tema propi. La configuració de l'app s'hauria d'haver modificat.",
    "Theming" : "Aparença",
    "Legal notice" : "Avís legal",
    "Privacy policy" : "Política de privadesa",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "La personalització permet canviar fàcilment l'aspecte de la vostra web i dels clients. Això serà visible per a tots els usuaris.",
    "Name" : "Nom",
    "Reset to default" : "Restablir al valor predeterminat",
    "https://…" : "https://...",
    "Slogan" : "Lema",
    "Color" : "Color",
    "Logo" : "Logotip",
    "Upload new logo" : "Penjar un nou logotip",
    "Login image" : "Login logo",
    "Upload new login background" : "Carregar nou fons d'inici de sessió",
    "Remove background image" : "Elimina la imatge de fons",
    "Advanced options" : "Opcions avançades",
    "Legal notice link" : "Enllaç a l'avís legal",
    "Privacy policy link" : "Enllaç a la política de privadesa",
    "Header logo" : "Logo de capçalera",
    "Upload new header logo" : "Pujar un nou logo de capçalera",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instal·la l'extensió Imagemagick per al PHP i es generarà automàticament un favicon a partir del logo i del color del tema."
},
"nplurals=2; plural=(n != 1);");
